@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class SieveEditorManageSieveWidget : public KSieveUi::ManageSieveWidget
     Q_OBJECT
 public:
     explicit SieveEditorManageSieveWidget(QWidget *parent = nullptr);
-    virtual ~SieveEditorManageSieveWidget();
+    ~SieveEditorManageSieveWidget() override;
 
 protected:
     bool refreshList() override;
